from typing import Union

from pydantic import dataclasses

@dataclasses.dataclass(config=dict(extra="allow"))
class AvatarDecorations:
    id: str
    url: str
    angle: float = None
    flipH: bool = None

@dataclasses.dataclass(config=dict(extra="allow"))
class User:
    id: str
    createdAt: str
    username: str
    host: Union[str, None] = None 
    name: Union[str, None] = None 
    avatarUrl: Union[str, None] = None 
    avatarBlurhash: Union[str, None] = None 
    avatarDecorations: list[Union[AvatarDecorations, None]] = None
    isAdmin: bool = False
    isModerator: bool = False
    isBot: bool = False
    isCat: bool = False
    onlineStatus: Union[str, None] = None

@dataclasses.dataclass(config=dict(extra="allow"))
class UserLite:
    id: str
    username: str
    name: Union[str, None] = None
    
    host: Union[str, None] = None
    avatarUrl: Union[str, None] = None
    avatarBlurhash: Union[str, None] = None
    avatarDecorations: list[Union[AvatarDecorations, None]] = None
    isAdmin: bool = False
    isModerator: bool = False
    isBot: bool = False
    isCat: bool = False
    onlineStatus: Union[str, None] = None


from typing import List, Union

from pydantic import dataclasses


@dataclasses.dataclass(config=dict(extra="allow"))
class Poll:
    choices: List[str]
    multiple: bool = False
    expiresAt: Union[int, None] = None
    expiredAfter: Union[int, None] = None



from typing import Union

from pydantic import dataclasses, Field

from .user import User, UserLite
from .drive import DriveFile

@dataclasses.dataclass(config=dict(extra="allow"))
class Note:
    id: str
    createdAt: str
    userId: str
    user: UserLite
    replyId: Union[str, None]
    renoteId: Union[str, None]
    visibility: str
    localOnly: bool

    reactions: Union[dict, None] = None
    myReaction: Union[dict, None] = None
    uri: Union[str, None] = None
    url: Union[str, None] = None
    renoteCount: Union[int, None] = None
    replyesCount: Union[int, None] = None
    isHidden: Union[bool, None] = None
    deletedAt: Union[str, None] = None
    text: Union[str, None] = None
    cw: Union[str, None] = None
    reply: Union[dict, None] = None
    renote: Union[dict, None] = None
    mentions: list[str] = Field(default_factory=list)
    visibleUserIds: list[str] = Field(default_factory=list)
    fileIds: list[str] = Field(default_factory=list)
    files: list[DriveFile] = Field(default_factory=list)
    tags: list[str] = Field(default_factory=list)
    poll: Union[dict, None] = None
    channelId: Union[str, None] = None
    channel: Union[dict, None] = None
    reactionAcceptance: Union[str, None] = None
    reactionAndUserPairCache: list[str] = Field(default_factory=list)


from typing import Union

from pydantic import dataclasses, Field

from .user import User

@dataclasses.dataclass(config=dict(extra="allow"))
class DriveFolder:
    id: str
    createdAt: str
    name: str
    foldersCount: int
    filesCount: int
    parentId: Union[str, None] = None
    parent: Union[dict, None] = Field(default_factory=dict)

@dataclasses.dataclass(config=dict(extra="allow"))
class df_property:
    width: Union[int, None] = None
    height: Union[int, None] = None
    orientation: Union[int, None] = None
    avgColor: Union[str, None] = None

@dataclasses.dataclass(config=dict(extra="allow"))
class DriveFile:
    id: str
    createdAt: str
    name: str
    type: str
    md5: str
    size: int
    properties: df_property
    isSensitive: bool = False
    blurhash: Union[str, None] = None
    url: Union[str, None] = None
    thumbnailUrl: Union[str, None] = None
    comment: Union[str, None] = None
    folderId: Union[str, None] = None
    folder: Union[DriveFolder, None] = None
    userId: Union[str, None] = None
    user: Union[User, None] = None


from typing import Union, List

from pydantic import dataclasses, Field


@dataclasses.dataclass(config=dict(extra="allow"))
class channel:
    id: str
    createdAt: str
    lastNotedAt: str
    name: str
    description: str
    bannerUrl: str
    isArchived: bool
    notedCount: int
    usersCount: int
    isFollowing: bool
    isFavorite: bool
    userId: str
    pinnedNoteIds: List[str]
    color: str
    isSensitive: bool
    allowRenoteToExternal: bool